// Copyright 2023 The Matrix.org Foundation C.I.C.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import { MUpstreamOauthProvider } from "./MUpstreamOauthProvider";
import { MUser } from "./MUser";

import { UUID } from "./index";

/*
+----------------------------+--------------------------+-----------+
| Column                     | Type                     | Modifiers |
|----------------------------+--------------------------+-----------|
| upstream_oauth_link_id     | uuid                     |  not null |
| upstream_oauth_provider_id | uuid                     |  not null |
| user_id                    | uuid                     |           |
| subject                    | text                     |  not null |
| created_at                 | timestamp with time zone |  not null |
+----------------------------+--------------------------+-----------+
Indexes:
    "upstream_oauth_links_pkey" PRIMARY KEY, btree (upstream_oauth_link_id)
    "upstream_oauth_links_subject_unique" UNIQUE CONSTRAINT, btree (upstream_oauth_provider_id, subject)
Foreign-key constraints:
    "upstream_oauth_link_user_fkey" FOREIGN KEY (user_id) REFERENCES users(user_id)
    "upstream_oauth_links_provider_fkey" FOREIGN KEY (upstream_oauth_provider_id) REFERENCES upstream_oauth_providers(upstream_oauth_provider_id)
Referenced by:
    TABLE "upstream_oauth_authorization_sessions" CONSTRAINT "upstream_oauth_authorization_sessions_link_fkey" FOREIGN KEY (upstream_oauth_link_id) REFERENCES upstream_oauth_links(upstream_oauth_link_id)
*/
export interface MUpstreamOauthLink {
  upstream_oauth_link_id: UUID<MUpstreamOauthLink>;
  upstream_oauth_provider_id: UUID<MUpstreamOauthProvider>;
  user_id?: UUID<MUser>;
  subject: string;
  created_at: Date;
}
